# pips3

Python Boilerplate contains all the boilerplate you need to create a Python package.

## Features

* TODO

### Credits

This package was created with [Cookiecutter(https://github.com/audreyr/cookiecutter) and the [annalise.ai cookiecutter](https://github.com/AnnaliseAI/pythonpackagecookie) project template.
